==> sped-1.35.26.tar.gz: sped-1.35.26/pythonsped/contribuicoes/layout_005.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from bloco_m import bloco_m as con_bloco_m
from bloco_c import bloco_c as con_bloco_c

_obrigatoriedade_ = '01/01/2019'
_codigo_ = '005'  # layout_005


class bloco_c(con_bloco_c):
    pass


class bloco_m(con_bloco_m):
    """
    BLOCO M – APURAÇÃO DA CONTRIBUIÇÃO E CRÉDITO DO PIS/PASEP E DA COFINS
    Os registros componentes dos Blocos “M” são escriturados na visão da empresa, diferentemente
    dos registros informados nos Blocos “A”, “C”, “D” e “F” que são informados na visão de cada
    estabelecimento da pessoa jurídica que realizou as operações gerados de contribuições sociais
    ou de créditos.
    """

    class registro_M210(con_bloco_m.registro_M210):
        """
        REGISTRO M210: DETALHAMENTO DA CONTRIBUIÇÃO PARA O PIS/PASEP DO PERÍODO
        """
        def __init__(self):
            super(bloco_m.registro_M210, self).__init__()
            self.VL_AJUS_ACRES_BC_PIS = ''
            self.VL_AJUS_REDUC_BC_PIS = ''
            self.VL_BC_CONT_AJUS = ''
            self.fieldnames = ('REG', 'COD_CONT', 'VL_REC_BRT', 'VL_BC_CONT',
                               'VL_AJUS_ACRES_BC_PIS', 'VL_AJUS_REDUC_BC_PIS', 'VL_BC_CONT_AJUS',
                               'ALIQ_PIS', 'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_CONT_APUR',
                               'VL_AJUS_ACRES', 'VL_AJUS_REDUC', 'VL_CONT_DIFER',
                               'VL_CONT_DIFER_ANT', 'VL_CONT_PER')
            self.formato = self.get_formato()


    class registro_M610(con_bloco_m.registro_M610):
        """

        """
        def __init__(self):
            super(bloco_m.registro_M610, self).__init__()
            self.VL_AJUS_ACRES_BC_COFINS = ''
            self.VL_AJUS_REDUC_BC_COFINS = ''
            self.VL_BC_CONT_AJUS = ''
            self.fieldnames = ('REG', 'COD_CONT', 'VL_REC_BRT', 'VL_BC_CONT',
                               'VL_AJUS_ACRES_BC_COFINS', 'VL_AJUS_REDUC_BC_COFINS',
                               'VL_BC_CONT_AJUS', 'ALIQ_COFINS', 'QUANT_BC_COFINS',
                               'ALIQ_COFINS_QUANT', 'VL_CONT_APUR', 'VL_AJUS_ACRES',
                               'VL_AJUS_REDUC', 'VL_CONT_DIFER', 'VL_CONT_DIFER_ANT', 'VL_CONT_PER')
            self.formato = self.get_formato()

==> sped-3.0.3.tar.gz: sped-3.0.3/pythonsped/contribuicoes/layout_005.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from .bloco_m import bloco_m as con_bloco_m
from .bloco_c import bloco_c as con_bloco_c

_obrigatoriedade_ = '01/01/2019'
_codigo_ = '005'  # layout_005


class bloco_c(con_bloco_c):
    pass


class bloco_m(con_bloco_m):
    """
    BLOCO M – APURAÇÃO DA CONTRIBUIÇÃO E CRÉDITO DO PIS/PASEP E DA COFINS
    Os registros componentes dos Blocos “M” são escriturados na visão da empresa, diferentemente
    dos registros informados nos Blocos “A”, “C”, “D” e “F” que são informados na visão de cada
    estabelecimento da pessoa jurídica que realizou as operações gerados de contribuições sociais
    ou de créditos.
    """

    class registro_M210(con_bloco_m.registro_M210):
        """
        REGISTRO M210: DETALHAMENTO DA CONTRIBUIÇÃO PARA O PIS/PASEP DO PERÍODO
        """
        def __init__(self):
            super(bloco_m.registro_M210, self).__init__()
            self.VL_AJUS_ACRES_BC_PIS = ''
            self.VL_AJUS_REDUC_BC_PIS = ''
            self.VL_BC_CONT_AJUS = ''
            self.fieldnames = ('REG', 'COD_CONT', 'VL_REC_BRT', 'VL_BC_CONT',
                               'VL_AJUS_ACRES_BC_PIS', 'VL_AJUS_REDUC_BC_PIS', 'VL_BC_CONT_AJUS',
                               'ALIQ_PIS', 'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_CONT_APUR',
                               'VL_AJUS_ACRES', 'VL_AJUS_REDUC', 'VL_CONT_DIFER',
                               'VL_CONT_DIFER_ANT', 'VL_CONT_PER')
            self.formato = self.get_formato()


    class registro_M610(con_bloco_m.registro_M610):
        """

        """
        def __init__(self):
            super(bloco_m.registro_M610, self).__init__()
            self.VL_AJUS_ACRES_BC_COFINS = ''
            self.VL_AJUS_REDUC_BC_COFINS = ''
            self.VL_BC_CONT_AJUS = ''
            self.fieldnames = ('REG', 'COD_CONT', 'VL_REC_BRT', 'VL_BC_CONT',
                               'VL_AJUS_ACRES_BC_COFINS', 'VL_AJUS_REDUC_BC_COFINS',
                               'VL_BC_CONT_AJUS', 'ALIQ_COFINS', 'QUANT_BC_COFINS',
                               'ALIQ_COFINS_QUANT', 'VL_CONT_APUR', 'VL_AJUS_ACRES',
                               'VL_AJUS_REDUC', 'VL_CONT_DIFER', 'VL_CONT_DIFER_ANT', 'VL_CONT_PER')
            self.formato = self.get_formato()
